from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_mailbox', '0003_auto_20150409_0316'),
    ]

    operations = [
        migrations.AlterField(
            model_name='message',
            name='eml',
            field=models.FileField(verbose_name='Raw message contents', upload_to='messages', null=True, help_text='Original full content of message'),
        ),
        migrations.AlterField(
            model_name='messageattachment',
            name='document',
            field=models.FileField(verbose_name='Document', upload_to='mailbox_attachments/%Y/%m/%d/'),
        ),
    ]



from unittest import mock

from django.core.management import call_command, CommandError
from django.test import TestCase


class CommandsTestCase(TestCase):
    def test_processincomingmessage_no_args(self):
        """Check that processincomingmessage works with no args"""

        mailbox_name = None
        # Mock handle so that the test doesn't hang waiting for input. Note that we are only testing
        # the argument parsing here -- functionality should be tested elsewhere
        with mock.patch('django_mailbox.management.commands.processincomingmessage.Command.handle') as handle:
            # Don't care about the return value
            handle.return_value = None

            call_command('processincomingmessage')
            args, kwargs = handle.call_args

            # Make sure that we called with the right arguments
            self.assertEqual(kwargs['mailbox_name'], mailbox_name)

    def test_processincomingmessage_with_arg(self):
        """Check that processincomingmessage works with mailbox_name given"""

        mailbox_name = 'foo_mailbox'

        with mock.patch('django_mailbox.management.commands.processincomingmessage.Command.handle') as handle:
            handle.return_value = None

            call_command('processincomingmessage', mailbox_name)
            args, kwargs = handle.call_args

            self.assertEqual(kwargs['mailbox_name'], mailbox_name)

    def test_processincomingmessage_too_many_args(self):
        """Check that processincomingmessage raises an error if too many args"""

        with self.assertRaises(CommandError):
            call_command('processincomingmessage', 'foo_mailbox', 'invalid_arg')



# Generated by Django 2.1.7 on 2019-02-19 14:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_mailbox', '0007_auto_20180421_0026'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mailbox',
            name='active',
            field=models.BooleanField(blank=True, default=True, help_text='Check this e-mail inbox for new e-mail messages during polling cycles.  This checkbox does not have an effect upon whether mail is collected here when this mailbox receives mail from a pipe, and does not affect whether e-mail messages can be dispatched from this mailbox. ', verbose_name='Active'),
        ),
        migrations.AlterField(
            model_name='message',
            name='outgoing',
            field=models.BooleanField(blank=True, default=False, verbose_name='Outgoing'),
        ),
    ]



import os

from django.test import TestCase

from django_mailbox.models import Mailbox


__all__ = ['TestMailbox']


class TestMailbox(TestCase):
    def test_protocol_info(self):
        mailbox = Mailbox()
        mailbox.uri = 'alpha://test.com'

        expected_protocol = 'alpha'
        actual_protocol = mailbox._protocol_info.scheme

        self.assertEqual(
            expected_protocol,
            actual_protocol,
        )

    def test_last_polling_field_exists(self):
        mailbox = Mailbox()
        self.assertTrue(hasattr(mailbox, 'last_polling'))

    def test_get_new_mail_update_last_polling(self):
        mailbox = Mailbox.objects.create(uri="mbox://" + os.path.join(
                os.path.dirname(__file__),
                'messages',
                'generic_message.eml',
            ))
        self.assertEqual(mailbox.last_polling, None)
        list(mailbox.get_new_mail())
        self.assertNotEqual(mailbox.last_polling, None)

    def test_queryset_get_new_mail(self):
        mailbox = Mailbox.objects.create(uri="mbox://" + os.path.join(
                os.path.dirname(__file__),
                'messages',
                'generic_message.eml',
            ))
        Mailbox.objects.filter(pk=mailbox.pk).get_new_mail()
        mailbox.refresh_from_db()
        self.assertNotEqual(mailbox.last_polling, None)



from django.db import migrations, models
import django_mailbox.utils


class Migration(migrations.Migration):

    dependencies = [
        ('django_mailbox', '0004_bytestring_to_unicode'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messageattachment',
            name='document',
            field=models.FileField(upload_to=django_mailbox.utils.get_attachment_save_path, verbose_name='Document'),
        ),
    ]



import os
import uuid
from urllib import parse

from django.core.mail import EmailMultiAlternatives

from django_mailbox.models import Mailbox
from django_mailbox.tests.base import EmailMessageTestCase


__all__ = ['TestImap']


class TestImap(EmailMessageTestCase):
    def setUp(self):
        super().setUp()

        self.test_imap_server = (
            os.environ.get('EMAIL_IMAP_SERVER')
        )

        required_settings = [
            self.test_imap_server,
            self.test_account,
            self.test_password,
            self.test_smtp_server,
            self.test_from_email,
        ]
        if not all(required_settings):
            self.skipTest(
                "Integration tests are not available without having "
                "the the following environment variables set: "
                "EMAIL_ACCOUNT, EMAIL_PASSWORD, EMAIL_SMTP_SERVER, "
                "EMAIL_IMAP_SERVER."
            )

        self.mailbox = Mailbox.objects.create(
            name='Integration Test Imap',
            uri=self.get_connection_string()
        )
        self.arbitrary_identifier = str(uuid.uuid4())

    def get_connection_string(self):
        return "imap+ssl://{account}:{password}@{server}".format(
            account=parse.quote(self.test_account),
            password=parse.quote(self.test_password),
            server=self.test_imap_server,
        )

    def test_get_imap_message(self):
        text_content = 'This is some content'
        msg = EmailMultiAlternatives(
            self.arbitrary_identifier,
            text_content,
            self.test_from_email,
            [
                self.test_account,
            ]
        )
        msg.send()

        messages = self._get_new_messages(
            self.mailbox,
            condition=lambda m: m['subject'] == self.arbitrary_identifier
        )
        message = next(messages)

        self.assertEqual(message.subject, self.arbitrary_identifier)
        self.assertEqual(message.text, text_content)
        self.assertEqual(0, len(list(messages)))



import logging

from django.conf import settings

from .base import EmailTransport, MessageParseError

logger = logging.getLogger(__name__)


class Office365Transport(EmailTransport):
    def __init__(
        self, hostname, username, archive='', folder=None
    ):
        self.integration_testing_subject = getattr(
            settings,
            'DJANGO_MAILBOX_INTEGRATION_TESTING_SUBJECT',
            None
        )
        self.hostname = hostname
        self.username = username
        self.archive = archive
        self.folder = folder

    def connect(self, client_id, client_secret, tenant_id):
        try:
            import O365
        except ImportError:
            raise ValueError(
                "Install o365 to use oauth2 auth for office365"
            )

        credentials = (client_id, client_secret)

        self.account = O365.Account(credentials, auth_flow_type='credentials', tenant_id=tenant_id)
        self.account.authenticate()

        self.mailbox = self.account.mailbox(resource=self.username)
        self.mailbox_folder = self.mailbox.inbox_folder()
        if self.folder:
            self.mailbox_folder = self.mailbox.get_folder(folder_name=self.folder)

    def get_message(self, condition=None):
        archive_folder = None
        if self.archive:
            archive_folder = self.mailbox.get_folder(folder_name=self.archive)
            if not archive_folder:
                archive_folder = self.mailbox.create_child_folder(self.archive)

        for o365message in self.mailbox_folder.get_messages(order_by='receivedDateTime'):
            try:
                mime_content = o365message.get_mime_content()
                message = self.get_email_from_bytes(mime_content)

                if condition and not condition(message):
                    continue

                yield message
            except MessageParseError:
                continue

            if self.archive and archive_folder:
                o365message.copy(archive_folder)

            o365message.delete()
        return



DATABASES = {
    'default': {
        'NAME': 'db.sqlite3',
        'ENGINE': 'django.db.backends.sqlite3',
    },
}
INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django_mailbox',
]
SECRET_KEY = 'beepboop'



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class MailBoxConfig(AppConfig):
    name = 'django_mailbox'
    verbose_name = _("Mail Box")

    default_auto_field = "django.db.models.AutoField"



# Generated by Django 1.10.7 on 2018-04-21 00:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_mailbox', '0006_mailbox_last_polling'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mailbox',
            options={'verbose_name': 'Mailbox', 'verbose_name_plural': 'Mailboxes'},
        ),
        migrations.AlterModelOptions(
            name='message',
            options={'verbose_name': 'E-mail message', 'verbose_name_plural': 'E-mail messages'},
        ),
        migrations.AlterModelOptions(
            name='messageattachment',
            options={'verbose_name': 'Message attachment', 'verbose_name_plural': 'Message attachments'},
        ),
    ]



# Generated by Django 1.9.8 on 2016-08-15 22:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_mailbox', '0005_auto_20160523_2240'),
    ]

    operations = [
        migrations.AddField(
            model_name='mailbox',
            name='last_polling',
            field=models.DateTimeField(blank=True, help_text='The time of last successful polling for messages.It is blank for new mailboxes and is not set for mailboxes that only receive messages via a pipe.', null=True, verbose_name='Last polling'),
        ),
    ]



import email

# Do *not* remove this, we need to use this in subclasses of EmailTransport
from email.errors import MessageParseError  # noqa: F401


class EmailTransport:
    def get_email_from_bytes(self, contents):
        message = email.message_from_bytes(contents)

        return message



import logging

from django.core.management.base import BaseCommand

from django_mailbox.models import Mailbox


class Command(BaseCommand):
    def handle(self, *args, **options):
        logging.basicConfig(level=logging.INFO)
        Mailbox.get_new_mail_all_mailboxes(args)



from setuptools import find_packages, setup

from django_mailbox import __version__ as version_string


tests_require = [
    'django',
    'mock',
    'unittest2',
]

gmail_oauth2_require = [
    'python-social-auth',
]

office365_oauth2_require = [
    'O365',
]

setup(
    name='django-mailbox',
    version=version_string,
    url='http://github.com/coddingtonbear/django-mailbox/',
    description=(
        'Import mail from POP3, IMAP, local mailboxes or directly from '
        'Postfix or Exim4 into your Django application automatically.'
    ),
    license='MIT',
    author='Adam Coddington',
    author_email='me@adamcoddington.net',
    extras_require={
        'gmail-oauth2': gmail_oauth2_require,
        'office365-oauth2': office365_oauth2_require
    },
    python_requires=">=3.8",
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'Framework :: Django :: 4.1',
        'Framework :: Django :: 4.2',
        'Framework :: Django :: 5.0',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Topic :: Communications :: Email',
        'Topic :: Communications :: Email :: Post-Office',
        'Topic :: Communications :: Email :: Post-Office :: IMAP',
        'Topic :: Communications :: Email :: Post-Office :: POP3',
        'Topic :: Communications :: Email :: Email Clients (MUA)',
    ],
    packages=find_packages(),
    include_package_data=True,
)
